<?php
/**
 * @file
 * This file contains all the base form id alters.
 */

/**
 * Implements hook_form_BASE_FORM_ID_alter().
 */
function openlucius_core_form_comment_node_ol_todo_form_alter(&$form, &$form_state, $form_id) {
  $menu_item = menu_get_item();

  // Load from form if possible.
  if (isset($form['#node']) && isset($form['#node']->field_shared_group_reference[LANGUAGE_NONE][0]['nid'])) {
    $group_id = $form['#node']->field_shared_group_reference[LANGUAGE_NONE][0]['nid'];
  }
  // This should happen on node/add.
  else {
    $group_id = $menu_item['page_arguments'][1];
  }

  $form['field_todo_list_reference'][LANGUAGE_NONE]['#options'] = openlucius_core_get_lists_in_group($group_id);
}

/**
 * Implements hook_form_BASE_FORM_ID_alter().
 */
function openlucius_core_form_user_register_form_alter(&$form, &$form_state, $form_id) {

  // Hide unpublished Groups.
  foreach ($form['field_groups'][LANGUAGE_NONE]['#options'] as $gid => $gname) {

    // Check Group status.
    $result = db_select('node', 'n')
      ->fields('n', array('status'))
      ->condition('n.nid', $gid, '=')
      ->execute()
      ->fetchField();

    // If Group is unpublished (archived), unset the gid.
    if ($result == '0') {
      unset($form['field_groups'][LANGUAGE_NONE]['#options'][$gid]);
    }
  }

  // Select groups that users are automatically added in.
  if ($form_id == 'user_register_form') {

    // Initialize the list for the groups.
    $group_list = array();

    // Get the selected groups from group/team configuration.
    $groups = variable_get('openlucius_core_groups', array());

    // Loop through the groups.
    foreach ($groups as $id => $boolean) {

      // Check if the group is selected.
      if ($boolean !== 0) {

        // Add the group to the list.
        $group_list[$id] = $id;
      }
    }

    // Check if the group parameter is set if so add to array if the user has
    // access.
    if (!empty($_GET['group']) && is_numeric($_GET['group']) && empty($group_list[$_GET['group']])) {
      $node = new stdClass();
      $node->nid = $_GET['group'];

      // Check if the user has access to the group.
      if (node_access('view', $node)) {
        $group_list[$_GET['group']] = $_GET['group'];
      }
    }

    if (isset($group_list) && is_array($group_list) && !empty($group_list)) {
      // Set the default value to select the required checkboxes.
      $form['field_groups'][LANGUAGE_NONE]['#default_value'] = array_values($group_list);
    }

    // Initialize the list for the teams.
    $team_list = array();
    // Get the selected teams from group/team configuration.
    $teams = variable_get('openlucius_core_teams', array());

    // Check of we have teams.
    if (!empty($teams)) {

      // Loop through the groups.
      foreach ($teams as $id => $boolean) {

        // Check if the group is selected.
        if ($boolean !== 0) {

          // Add the group to the list.
          $team_list[$id] = $id;
        }
      }
    }

    // Check if we have teams.
    if (!empty($team_list)) {

      // Set the default value to select the required checkboxes.
      $form['field_user_teams'][LANGUAGE_NONE]['#default_value'] = array_values($team_list);
    }
  }
}

/**
 * Implements hook_form_BASE_FORM_ID_alter().
 */
function openlucius_core_form_user_profile_form_alter(&$form, &$form_state, $form_id) {

  // Hide hash.
  if (!empty($form['field_user_hash'])) {
    $form['field_user_hash']['#access'] = FALSE;
    $form['mimemail']['#access'] = FALSE;
  }

  // Loop through the fields.
  foreach ($form as $field => $values) {

    // Check for the machine name of the field.
    if (stripos($field, 'field_') !== FALSE) {

      // Check if there is no group yet.
      if (empty($form['#group_children'][$field])) {

        // Place the field in the info tab.
        $form['#group_children'][$field] = 'group_user_info_tab';
      }
    }
  }
}

/**
 * Implements hook_form_BASE_FORM_ID_alter().
 */
function openlucius_core_form_ol_todo_node_form_alter(&$form, &$form_state, $form_id) {
  // Fetch the active menu_item.
  $menu = menu_get_item();

  // Fetch group id from either menu or form (on edit).
  $group_id = isset($menu['page_arguments'][1]) ? $menu['page_arguments'][1] : (isset($form['#node']->field_shared_group_reference[LANGUAGE_NONE][0]) ? $form['#node']->field_shared_group_reference[LANGUAGE_NONE][0]['nid'] : 0);

  // Check if the argument is numeric.
  if (is_numeric($group_id)) {

    // Load all users in this group and replace the existing options.
    $users_in_group = openlucius_core_fetch_users('group', $group_id);
    $options        = array('_none' => '- ' . t('None') . ' -');

    // Add those users to the options.
    foreach ($users_in_group as $entity) {
      $options[$entity->uid] = $entity->name;
    }
    $form['field_todo_user_reference'][LANGUAGE_NONE]['#options'] = $options;

    // Get the lists in the current group.
    $lists = openlucius_core_get_lists_in_group($group_id);

    // Check if there are no lists.
    if (empty($lists)) {

      // Set a message telling the user there is no todo_list yet.
      drupal_set_message(t('There is no todo list yet, please add one first by clicking <a href="@here">here</a>', array(
        '@here' => url('node/add/ol-todo-list/' . $group_id, array(
          'query' => array(
            'destination' => 'node/add/ol-todo/' . $group_id,
          ),
        )),
      )));
    }
  }
}

/**
 * Implements hook_form_BASE_FORM_ID_alter().
 */
function openlucius_core_form_node_form_alter(&$form, &$form_state, $form_id) {
  global $user;

  // Check for node add form.
  if (!isset($form['#node']->nid)) {

    // Get the user signature.
    $signature = openlucius_core_get_user_signature($user->uid);

    // Check if there should be a signature checkbox.
    if (in_array($form['#node']->type, openlucius_core_get_content_types_with_signature()) && !empty($signature)) {
      // Show signature checkbox.
      $form['field_show_signature'] = array(
        '#title'         => t('Show signature'),
        '#type'          => 'checkbox',
        '#weight'        => 7,
        '#default_value' => 0,
      );
    }
  }

  // Check for admin user.
  if ($user->uid == 1) {

    // Hide additional settings.
    $form['revision_information']['#attributes']['style'] = 'display:none !important;';
    $form['author']['#attributes']['style']               = 'display:none !important;';
    $form['options']['#attributes']['style']              = 'display:none !important;';
    $form['menu']['#attributes']['style']                 = 'display:none !important;';
    $form['comment_settings']['#attributes']['style']     = 'display:none !important;';

    // Switch to hidden.
    $form['additional_settings']['#type'] = 'hidden';
  }

  if (!empty($form['field_shared_weight'])) {
    $form['field_shared_weight']['#access'] = FALSE;
  }

  // Add settings for group Apps.
  if ($form['#node']->type == 'ol_group') {

    // Fetch the default buttons and paths.
    $default_buttons = openlucius_core_default_group_header_buttons();

    // Fetch all group settings.
    $group_settings = variable_get('openlucius_core_group_settings');

    // Get the keys of the buttons and build options list.
    $keys = array_keys($default_buttons);
    $options = array();
    foreach ($keys as $key) {
      $options[$key] = ucfirst(str_replace('_', '-', $key));

      // TODO translate this.
    }

    // Build the group app settings for this group.
    $form['openlucius_core_group_settings'] = array(
      '#type' => 'checkboxes',
      '#title' => t('Enabled Apps'),
      '#options' => $options,
      '#default_value' => isset($form['#node']->nid) && $group_settings[$form['#node']->nid] ? $group_settings[$form['#node']->nid] : $keys,
    );

    // Place the form elements in the app tab.
    $form['#group_children']['openlucius_core_group_settings'] = 'group_enabled_apps';

    // Add any remaining items to the first tab.
    $keys = array_keys($form['#group_children']);
    foreach($form as $key => $item) {
      if (stripos($key, 'field_') !== FALSE && !in_array($key, $keys)) {
        $form['#group_children'][$key] = 'group_primary';
      }
    }
  }
}

/**
 * Implements hook_form_BASE_FORM_ID_alter().
 */
function openlucius_core_form_views_exposed_form_alter(&$form, &$form_state, $form_id) {

  // Add the option to show everything.
  if ($form['#id'] == 'views-exposed-form-all-todo-lists-in-a-group-page-1') {
    $all                                      = array('All' => t('- Any -'));
    $form['field_todo_label_tid']['#options'] = $all + $form['field_todo_label_tid']['#options'];
  }

  // The form ids to limit the users.
  $form_ids = array(
    'views-exposed-form-all-todo-lists-in-a-group-page-2',
    'views-exposed-form-group-calendar-page-5',
  );

  // On this form limit the users to users in your own groups.
  if (in_array($form['#id'], $form_ids)) {

    global $user;
    $account = user_load($user->uid);

    // Views option for all.
    $options['All'] = t('- Any -');

    // Loop the groups of the current user.
    foreach ($account->field_groups[LANGUAGE_NONE] as $group) {

      // Get all the users in the group.
      $users_in_group = openlucius_core_fetch_users('group', $group['nid']);

      // Add those users to the options.
      foreach ($users_in_group as $entity) {
        $options[$entity->uid] = $entity->name;
      }
    }

    // Replace the options.
    $form['field_todo_user_reference_uid']['#options'] = $options;
  }
  if ($form['#id'] == 'views-exposed-form-group-calendar-page-5' || $form['#id'] == 'views-exposed-form-group-calendar-page-4') {

    // Get the closed term.
    $closed = current(taxonomy_get_term_by_name('closed', 'labels_todo_s'));

    // Remove closed from the options.
    unset($form['field_todo_label_tid_1']['#options'][$closed->tid]);
  }

  // Change submit button for user search view.
  if ($form['#id'] == 'views-exposed-form-user-search-page') {
    $form['submit']['#value'] = t('Search');
  }

  // Filter on users in this group.
  if ($form['#id'] == 'views-exposed-form-todos-on-todo-list-page-block') {

    // Get the menu object.
    $object = menu_get_object();

    // Check if the group is set.
    if (!empty($object->field_shared_group_reference[LANGUAGE_NONE][0]['nid'])) {

      // Get all the users in the group.
      $users_in_group = openlucius_core_fetch_users('group', $object->field_shared_group_reference[LANGUAGE_NONE][0]['nid']);

      // Views option for all.
      $options['All'] = t('- Any -');

      // Add those users to the options.
      foreach ($users_in_group as $entity) {
        $options[$entity->uid] = $entity->name;
      }

      // Replace the options.
      $form['field_todo_user_reference_uid']['#options'] = $options;
    }
  }
}
