/**
 * @file
 * This file contains all jQuery for the OpenLucius Core module.
 */
(function ($) {
  Drupal.behaviors.openlucius_core = {
    attach: function (context, settings) {

      // Only trigger once to not interfere with the timetracker.
      if (context == document) {

        // Present throbber for elements with throbber class.
        $('.openlucius-throbber').click(function() {
          $('body').addThrobber();
        });

        // Trigger on click of the font awesome icon.
        $(".group-local-tasks-wrapper .fa").click(function (e) {

          // Toggle the class 'shown' on the wrapper span (group-local-tasks-wrapper).
          $(this).parent().toggleClass("shown");
        });

        // Close the menu when clicking anywhere.
        $(document).click(function(event) {
          var el = $('.group-local-tasks-wrapper.shown');

          if(!$(event.target).closest('.shown', el).length) {
            if($(el).is(":visible")) {
              el.toggleClass("shown");
            }
          }
        });

        // Get the sidebar submit button.
        var submit_button = $('.region-sidebar-second #node-submit');
        // Check for the fake node-submit form button in the sidebar.
        if (submit_button.length > 0) {
          // Register on click event.
          submit_button.on("click", function() {
            // Get the node form.
            var node_form = $('.node-form');
            // Check for the node form.
            if (node_form.length > 0) {
              // Submit the node form.
              node_form.submit();
            }
          });
        }

        // Get the limit for the todos on the dashboard.
        var todoLimit = settings.hasOwnProperty('openlucius_core_dashboard_todo_limit')  ? settings.openlucius_core_dashboard_todo_limit : 5;

        // Add one to skip the add inline todo row.
        todoLimit = parseInt(todoLimit, 10) + 1;

        // Get column count.
        var columns = $(".view-id-todos_in_group_dashboard table").find('tr:nth-child(2) td').length;

        // Loop through each table in the group dashboard.
        $(".view-id-todos_in_group_dashboard table").each(function() {

          // Get all items in each table.
          var items = $('tbody tr', $(this));

          // Check if we have enough items.
          if (items.length > (todoLimit)) {

            // Loop through the items.
            items.each(function (index) {

              // After item x.
              if (index > (todoLimit - 1)) {

                // Add css to hide the item.
                $(this).css({'display': 'none'});
              }
            });

            // Add a table row with a show more button.
            $(this).append('<tr class="add-more" style="background:none;"><td style="text-align:center;" colspan="' + columns + '"><a href="#" class="show-more">' + Drupal.t('Show more') + '</a></td></tr>');
          }
        });

        // Bind a click to the show more button.
        $('.add-more .show-more').on('click', function(event) {

          // Prevent default link behaviour.
          event.preventDefault();

          // Get the parent tbody and items.
          var parent = $(this).parents("tbody"),
            items = null;

          // Check if the table is unfolded.
          if ($(this).hasClass('open')) {
            items = $('tr', parent).slice(todoLimit, -1);
            $(this).removeClass('open').text(Drupal.t('Show more'));

            // Loop through the items.
            items.each(function() {

              // Make the item fade out.
              $(this).fadeOut("slow");
            });
          }
          else {
            items = $('tr', parent);
            $(this).addClass('open').text(Drupal.t('Show less'));

            // Loop through the items.
            items.each(function() {

              // Make the item fade in.
              $(this).fadeIn("slow");
            });
          }
        });
      }

      // Trigger on click for both show-more and show-less links.
      $(".timeline .show-more, .timeline .show-less").click(function (e) {

        // Toggle the class 'shown' on the wrapper div (notified).
        $(this).parent().toggleClass("shown");
      });
    }
  };
})(jQuery);
